# bot_discord.py
import discord
from discord.ext import commands
import importlib
import cmd_discord

class DiscordBot(commands.Bot):
    def __init__(self, config, logger):
        super().__init__(command_prefix="!", intents=discord.Intents.all())
        self.config = config
        self.logger = logger
        self.load_commands()

    def load_commands(self):
        """
        Load all commands dynamically from cmd_discord.py.
        """
        try:
            importlib.reload(cmd_discord)
            cmd_discord.setup(self)
            self.logger.info("Discord commands loaded successfully.")
        except Exception as e:
            self.logger.error(f"Error loading Discord commands: {e}")

    async def on_ready(self):
        self.logger.info(f"Discord bot is online as {self.user}")

#    @commands.command()
#    async def reload(self, ctx):
#        """ Reload all Discord commands dynamically. """
#        self.load_commands()
#        await ctx.send("Commands reloaded!")

    async def run(self, token):
        try:
            await super().start(token)
        except Exception as e:
            self.logger.error(f"Discord bot error: {e}")
